@@ -7,15 +7,13 @@ from trell import aws
 
 def ClickHouse():
 
-    def __init__()
+    def __init__():
 
         try:
-            self.db_connection_str = "clickhouse://"+aws.cred['CLICKHOUSE_USER']+":"+aws.cred['CLICKHOUSE_PASS']+"@"+aws.cred['CLICKHOUSE_HOST']+":"+ 
-                aws.cred['CLICKHOUSE_PORT'] +"/"+ aws.cred['CLICKHOUSE_DB']
+            self.db_connection_str = "clickhouse://"+aws.cred['CLICKHOUSE_USER']+":"+aws.cred['CLICKHOUSE_PASS']+"@"+aws.cred['CLICKHOUSE_HOST']+":"+ aws.cred['CLICKHOUSE_PORT'] +"/"+ aws.cred['CLICKHOUSE_DB']
             self.db_connection = create_engine(self.db_connection_str)
         except Exception as err:
             print(str(err))
-  
 
     def write_clickhouse_data(self, dataframe, tableName, dbName):
         try:
