@@ -1,9 +1,14 @@
 import os
 import json
 import logging
+import traceback
 from datetime import datetime
 
 
+logging.basicConfig(format='%(asctime)s  %(levelname)s--> %(message)s', 
+                    datefmt='%d/%b/%Y %H:%M:%S %p %Z', level=logging.INFO)
+logger = logging.getLogger('trell_logger')
+
 class LogFormatter(logging.Formatter):
     """Log Formatter class for trell ai usage"""
 
